/*
 * Funambol is a mobile platform developed by Funambol, Inc. 
 * Copyright (C) 2005-2007 Funambol, Inc.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission 
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY FUNAMBOL, FUNAMBOL DISCLAIMS THE 
 * WARRANTY OF NON INFRINGEMENT  OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License 
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA.
 * 
 * You can contact Funambol, Inc. headquarters at 643 Bair Island Road, Suite 
 * 305, Redwood City, CA 94063, USA, or at email address info@funambol.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by Funambol" logo. If the display of the logo is not reasonably 
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by Funambol".
 */
package com.funambol.syncclient.ipod;

import java.awt.Font;
import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.JMenuBar;
import javax.swing.JMenu;
import javax.swing.JMenuItem;

import com.funambol.syncclient.ipod.utils.Language;
import com.funambol.syncclient.ipod.panels.AboutPanel;
import com.funambol.syncclient.ipod.panels.CommunicationSetPanel;
import com.funambol.syncclient.ipod.panels.LogPanel;
import com.funambol.syncclient.ipod.panels.SyncSetPanel;

/**
 * The menu bar for this GUI.
 *
 * @version $Id: MenuBar.java,v 1.2 2007-12-23 18:05:22 nichele Exp $
 */
public class MenuBar extends JMenuBar implements ActionListener {

    // ------------------------------------------------------------ Private Data
    private Font       font         = new Font("Microsoft Sans Serif", 0, 12);
    private JMenu      menu         = null;
    private JMenuItem  menuItem     = null;
    private JMenuItem  syncMenuItem = null;
    private MainWindow mainWindow   = null;
    private Color      color        = new Color(236,233,216);

    // ------------------------------------------------------------ Constructors
    public MenuBar(MainWindow mainWindow) {

        this.mainWindow = mainWindow;

        setBackground(color);

        //
        // File Menu
        //
        menu = new JMenu(Language.getMessage(Language.MENU_FILE));
        menu.setBackground(color);
        menu.setFont(font);

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_FILE_SYNC));
        menuItem.setFont(font);
        menuItem.setBackground(Color.WHITE);
        menuItem.setActionCommand("SYNCHRONIZATION");
        menuItem.addActionListener(this);
        menu.add(menuItem);
        syncMenuItem = menuItem;

        menu.addSeparator();

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_FILE_EXIT));
        menuItem.setFont(font);
        menuItem.setBackground(Color.WHITE);
        menuItem.setActionCommand("EXIT");
        menuItem.addActionListener(this);
        menu.add(menuItem);
        add(menu);

        //
        // Edit Menu
        //
        menu = new JMenu(Language.getMessage(Language.MENU_EDIT));
        menu.setBackground(color);
        menu.setFont(font);

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_EDIT_COMMUNICATION_SET));
        menuItem.setBackground(Color.WHITE);
        menuItem.setFont(font);
        menuItem.setActionCommand("COMMUNICATIONSET");
        menuItem.addActionListener(this);
        menu.add(menuItem);

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_EDIT_SYNC_SET));
        menuItem.setBackground(Color.WHITE);
        menuItem.setFont(font);
        menuItem.setActionCommand("SYNCSET");
        menuItem.addActionListener(this);
        menu.add(menuItem);
        add(menu);

        //
        // Help Menu
        //
        menu = new JMenu(Language.getMessage(Language.MENU_HELP));
        menu.setBackground(color);
        menu.setFont(font);

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_HELP_LOG));
        menuItem.setBackground(Color.WHITE);
        menuItem.setFont(font);
        menuItem.setActionCommand("VIEWLOG");
        menuItem.addActionListener(this);
        menu.add(menuItem);

        menu.addSeparator();

        menuItem = new JMenuItem(Language.getMessage(Language.MENU_HELP_ABOUT));
        menuItem.setBackground(Color.WHITE);
        menuItem.setFont(font);
        menuItem.setActionCommand("ABOUT");
        menuItem.addActionListener(this);
        menu.add(menuItem);

        add(menu);

    }
    
    // ---------------------------------------------------------- Public Methods
    
    public void actionPerformed(ActionEvent e) {
        if (e.getActionCommand().equals("SYNCHRONIZATION")) {
            mainWindow.runSynchronization();
        } else if(e.getActionCommand().equals("COMMUNICATIONSET")) {
            mainWindow.checkDeviceID();
            mainWindow.loadConfiguration();
            CommunicationSetPanel c = new CommunicationSetPanel(mainWindow,true);
            c.show();
        } else if(e.getActionCommand().equals("SYNCSET")) {
            SyncSetPanel ssp = new SyncSetPanel(mainWindow,true);
            ssp.show();
        } else if(e.getActionCommand().equals("VIEWLOG")) {
            LogPanel lp = new LogPanel(mainWindow,true);
            lp.show();
        } else if(e.getActionCommand().equals("ABOUT")) {
            AboutPanel ap = new AboutPanel(mainWindow,true);
            ap.show();
        } else if(e.getActionCommand().equals("EXIT")) {
            mainWindow.exit();
        }

    }
    
    /**
     * Enable/disable the synchronization option of the File menu.
     * @param enabled it must be equals to <code>true</code> to enable the 
     * synchronization option, <code>false</code> to disable
     */
    public void setEnableSyncMenuItem(boolean enabled){
        syncMenuItem.setEnabled(enabled);
    }
    
}