/*
 * Funambol is a mobile platform developed by Funambol, Inc. 
 * Copyright (C) 2005-2007 Funambol, Inc.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission 
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY FUNAMBOL, FUNAMBOL DISCLAIMS THE 
 * WARRANTY OF NON INFRINGEMENT  OF THIRD PARTY RIGHTS.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Affero General Public License 
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA.
 * 
 * You can contact Funambol, Inc. headquarters at 643 Bair Island Road, Suite 
 * 305, Redwood City, CA 94063, USA, or at email address info@funambol.com.
 * 
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 * 
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by Funambol" logo. If the display of the logo is not reasonably 
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by Funambol".
 */
package com.funambol.syncclient.ipod.panels;

import java.io.File;
import java.io.FileReader;
import java.io.BufferedReader;
import java.io.IOException;

import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.GridBagLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JDialog;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JPanel;
import javax.swing.JButton;
import javax.swing.UIManager;
import javax.swing.SwingConstants;

import com.funambol.syncclient.ipod.MainWindow;
import com.funambol.syncclient.ipod.utils.Constants;
import com.funambol.syncclient.ipod.utils.Language;
import com.funambol.syncclient.ipod.utils.UIUtil;

/**
 * The Logging window.
 *
 * @version $Id: LogPanel.java,v 1.3 2007-12-23 18:05:22 nichele Exp $
 */
public class LogPanel extends JDialog implements ActionListener, Constants {

    // ------------------------------------------------------------ Private Data
    private MainWindow mainWindow ;
    private boolean modal = false ;

    private JButton     jbClose     ;
    private JScrollPane jScrollPane1;
    private JTextArea   jTextArea   ;
    private JPanel      jPanel      ;

    // ---------------------------------------------------------- Public Methods

    /** Creates new form JDialog */
    public LogPanel(MainWindow mainWindow, boolean modal) {
        super(mainWindow, modal);
        this.mainWindow = mainWindow;
        this.modal      = modal     ;

        initComponents();
        getFileLog();
    }

    /**
     * This method is called from within the constructor to
     * initialize the form.
     */
    private void initComponents() {
        jbClose      = new JButton()    ;
        jScrollPane1 = new JScrollPane();
        jTextArea    = new JTextArea()  ;
        jPanel       = new JPanel()     ;

        try {
            UIManager.setLookAndFeel(lookAndFeel);
        } catch(Exception e) {
            e.printStackTrace();
        }

        //
        // Set up the window.
        //
        getContentPane().setLayout(new BorderLayout(1,1));
        setTitle(Language.getMessage(Language.LABEL_TITLE_LOGWINDOW));
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setSize(600,600);
        setLocationRelativeTo(null);
        setFont(FONT);
        setName("logDialog");
        setResizable(true);

        jTextArea.setEditable(false);
        jTextArea.setFont(FONT);
        jTextArea.setBackground(Color.WHITE);
        jScrollPane1.setAutoscrolls(true);
        jScrollPane1.setViewportView(jTextArea);
        getContentPane().add(jScrollPane1, BorderLayout.CENTER);

        jPanel.setLayout(new GridBagLayout());
        jPanel.setBackground(Color.WHITE);
        jPanel.setPreferredSize(new Dimension(400, 50));
        getContentPane().add(jPanel, BorderLayout.SOUTH);

        jbClose.setText(Language.getMessage(Language.BT_CLOSE));
        jbClose.setFont(FONT);
        jbClose.setPreferredSize(new Dimension(88, 23));
        jbClose.setVerticalAlignment(SwingConstants.CENTER);
        jbClose.setHorizontalAlignment(SwingConstants.CENTER);
        jbClose.addActionListener(this);
        jbClose.requestFocus(true);
        jPanel.add(jbClose);
    }

    public void actionPerformed(ActionEvent evt) {
        removeAll();
        setVisible(false);
    }

    /**
     * Read the file with logging to show
     */
    private void getFileLog() {
        try {
            File logfile = mainWindow.getFileLog();
            if (logfile != null) {
                FileReader fr = new FileReader(logfile);
                BufferedReader buf = new BufferedReader(fr);

                String line = null;
                while ((line = buf.readLine()) != null) {
                    jTextArea.append(line);
                    jTextArea.append("\n");
                }
                buf.close();
            }
        } catch (IOException e) {
            e.printStackTrace();
            System.exit(1);
        }
    }

}
