/*
 * Funambol is a mobile platform developed by Funambol, Inc.
 * Copyright (C) 2005 - 2007 Funambol, Inc.
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Affero General Public License version 3 as published by
 * the Free Software Foundation with the addition of the following permission
 * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
 * WORK IN WHICH THE COPYRIGHT IS OWNED BY FUNAMBOL, FUNAMBOL DISCLAIMS THE
 * WARRANTY OF NON INFRINGEMENT  OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301 USA.
 *
 * You can contact Funambol, Inc. headquarters at 643 Bair Island Road, Suite
 * 305, Redwood City, CA 94063, USA, or at email address info@funambol.com.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License
 * version 3, these Appropriate Legal Notices must retain the display of the
 * "Powered by Funambol" logo. If the display of the logo is not reasonably
 * feasible for technical reasons, the Appropriate Legal Notices must display
 * the words "Powered by Funambol".
 */

package com.funambol.syncclient.ipod.utils;

import java.awt.AWTError;
import java.awt.Image;
import java.awt.Toolkit;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.UIManager;


/**
 *
 * @version $Id: UIUtil.java,v 1.6 2007-12-24 09:21:47 nichele Exp $
 */
public class UIUtil {

    /**
     * Loads an image from the application resources.
     *
     * @param path icon full name as stored in the jar containing it - NOT NULL
     * @return the image if the resource is found
     * @throws AWTError if the image is not found
     */
    public static Image getImage(String path) throws AWTError {
        URL imgURL = UIUtil.class.getResource(path);
        if (imgURL != null) {
            return Toolkit.getDefaultToolkit().getImage(imgURL);
        } else {
            throw new AWTError(path + " resource not found!");
        }
    }

    /**
     * Loads an icon (as a ImageIcon) from the application resources.
     *
     * @param path icon full name as stored in the jar containing it - NOT NULL
     * @return the icon if the resource is found or an empty icon if not
     * @throws AWTError if the image is not found
     */
    public static ImageIcon getImageIcon(String path) throws AWTError {
        URL imgURL = UIUtil.class.getResource(path);
        if (imgURL != null) {
            return new ImageIcon(imgURL);
        } else {
            throw new AWTError(path + " resource not found!");
        }
    }

    /**
     * Returns the suitable look&feel based on the OS platform.
     *
     * @return the look&feel to use based on the value of the system property
     *         os.name
     */
    public static String getLookAndFeel(){
        String os = System.getProperty("os.name");
        if( os.equalsIgnoreCase("Windows 98")
            || os.equalsIgnoreCase("Windows NT")
            || os.equalsIgnoreCase("Windows 2000")
            || os.equalsIgnoreCase("Windows XP")
        ) {
            return "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";
        } else {
            return UIManager.getSystemLookAndFeelClassName();
        }
    }


}
